
from ctypes import windll


# from wincon.h
class WinColor(object):
    BLACK   = 0
    BLUE    = 1
    GREEN   = 2
    CYAN    = 3
    RED     = 4
    MAGENTA = 5
    YELLOW  = 6
    GREY    = 7

# from wincon.h
class WinStyle(object):
    DIM    = 0x00
    NORMAL = 0x08
    BRIGHT = 0x88

# from winbase.h
STD_OUTPUT_HANDLE= -11
HANDLE = windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)


class WinTerm(object):

    def __init__(self):
        self.reset_all()

    @property
    def combined_attrs(self):
        return self._fore + self._back * 16 + self._style

    def reset_all(self):
        self._fore = WinColor.GREY
        self._back = WinColor.BLACK
        self._style = WinStyle.NORMAL
        self.set_console()

    def fore(self, fore=None):
        if fore is None:
            fore = WinColor.GREY
        self._fore = fore
        self.set_console()

    def back(self, back=None):
        if back is None:
            back = WinColor.BLACK
        self._back = back
        self.set_console()

    def style(self, style=None):
        self._style = style
        self.set_console()

    def set_console(self):
        windll.kernel32.SetConsoleTextAttribute(HANDLE, self.combined_attrs)




import sys
import atexit

from .ansi import Style
from .ansitowin32 import AnsiToWin32

orig_stdout = sys.stdout
orig_stderr = sys.stderr

def init(autoreset=False, wrap=True):

    if autoreset==True and wrap==False:
        raise ValueError('autoreset=True conflicts with wrap=False')

    if (sys.platform.startswith('win') and wrap) or autoreset:
        sys.stdout = wrap_stream(sys.stdout, autoreset)
        sys.stderr = wrap_stream(sys.stderr, autoreset)
    else:
        sys.stdout = orig_stdout
        sys.stderr = orig_stderr

    atexit.register(reset_all)


def wrap_stream(stream, autoreset):
    real_stream = stream
    if isinstance(stream, AnsiToWin32):
        real_stream = stream.wrapped
    return AnsiToWin32(real_stream, autoreset=autoreset)


def reset_all():
    AnsiToWin32(orig_stdout).write(Style.RESET_ALL)





import sys
from unittest2 import TestCase, main

from colorama import init, Fore, Back, Style, AnsiToWin32


stdout_orig = sys.stdout
stderr_orig = sys.stderr


class AnsiTest(TestCase):
    
    def setUp(self):
        # sanity check: stdout should be a file or StringIO object.
        # It will only be AnsiToWin32 if init() has previously wrapped it
        self.assertNotEqual(type(sys.stdout), AnsiToWin32)
        self.assertNotEqual(type(sys.stderr), AnsiToWin32)

    def tearDown(self):
        sys.stdout = stdout_orig
        sys.stderr = stderr_orig


    def testForeAttributes(self):
        self.assertEquals(Fore.BLACK, '\033[30m')
        self.assertEquals(Fore.RED, '\033[31m')
        self.assertEquals(Fore.GREEN, '\033[32m')
        self.assertEquals(Fore.YELLOW, '\033[33m')
        self.assertEquals(Fore.BLUE, '\033[34m')
        self.assertEquals(Fore.MAGENTA, '\033[35m')
        self.assertEquals(Fore.CYAN, '\033[36m')
        self.assertEquals(Fore.WHITE, '\033[37m')
        self.assertEquals(Fore.RESET, '\033[39m')


    def testBackAttributes(self):
        self.assertEquals(Back.BLACK, '\033[40m')
        self.assertEquals(Back.RED, '\033[41m')
        self.assertEquals(Back.GREEN, '\033[42m')
        self.assertEquals(Back.YELLOW, '\033[43m')
        self.assertEquals(Back.BLUE, '\033[44m')
        self.assertEquals(Back.MAGENTA, '\033[45m')
        self.assertEquals(Back.CYAN, '\033[46m')
        self.assertEquals(Back.WHITE, '\033[47m')
        self.assertEquals(Back.RESET, '\033[49m')


    def testStyleAttributes(self):
        self.assertEquals(Style.DIM, '\033[2m')
        self.assertEquals(Style.NORMAL, '\033[22m')
        self.assertEquals(Style.BRIGHT, '\033[1m')


if __name__ == '__main__':
    main()





import re
import sys

from .ansi import AnsiFore, AnsiBack, AnsiStyle

try:
    from .winterm import WinColor, WinStyle, WinTerm
    winterm = WinTerm()
except ImportError:
    winterm = None


win32_calls = {
    AnsiStyle.RESET_ALL: lambda: winterm.reset_all(),
    AnsiStyle.BRIGHT: lambda: winterm.style(WinStyle.BRIGHT),
    AnsiStyle.DIM: lambda: winterm.style(WinStyle.DIM),
    AnsiStyle.NORMAL: lambda: winterm.style(WinStyle.NORMAL),
    AnsiFore.BLACK: lambda: winterm.fore(WinColor.BLACK),
    AnsiFore.RED: lambda: winterm.fore(WinColor.RED),
    AnsiFore.GREEN: lambda: winterm.fore(WinColor.GREEN),
    AnsiFore.YELLOW: lambda: winterm.fore(WinColor.YELLOW),
    AnsiFore.BLUE: lambda: winterm.fore(WinColor.BLUE),
    AnsiFore.MAGENTA: lambda: winterm.fore(WinColor.MAGENTA),
    AnsiFore.CYAN: lambda: winterm.fore(WinColor.CYAN),
    AnsiFore.WHITE: lambda: winterm.fore(WinColor.GREY),
    AnsiFore.RESET: lambda: winterm.fore(),
    AnsiBack.BLACK: lambda: winterm.back(WinColor.BLACK),
    AnsiBack.RED: lambda: winterm.back(WinColor.RED),
    AnsiBack.GREEN: lambda: winterm.back(WinColor.GREEN),
    AnsiBack.YELLOW: lambda: winterm.back(WinColor.YELLOW),
    AnsiBack.BLUE: lambda: winterm.back(WinColor.BLUE),
    AnsiBack.MAGENTA: lambda: winterm.back(WinColor.MAGENTA),
    AnsiBack.CYAN: lambda: winterm.back(WinColor.CYAN),
    AnsiBack.WHITE: lambda: winterm.back(WinColor.GREY),
    AnsiBack.RESET: lambda: winterm.back(),
}


class AnsiToWin32(object):

    ANSI_RE = re.compile('\033\[((?:\d|;)*)([a-zA-Z])')

    def __init__(self, wrapped, autoreset=False):
        self.wrapped = wrapped
        self.autoreset = autoreset
        self.enabled = sys.platform.startswith('win')
        self.winterm = winterm


    def __getattr__(self, name):
        return getattr(self.wrapped, name)


    def write(self, text):
        if self.enabled:
            self.write_and_convert(text)
            if self.autoreset:
                self.winterm.reset_all()
        else:
            self.wrapped.write(text)


    def write_and_convert(self, text):
        cursor = 0
        for match in self.ANSI_RE.finditer(text):
            start, end = match.span()
            self.write_snippet(text, cursor, start)

            paramstring, command = match.groups()
            params = self.extract_params(paramstring)
            self.call_win32(command, params)

            cursor = end

        self.write_snippet(text, cursor, len(text))


    def write_snippet(self, text, start, end):
        if start < end:
            self.wrapped.write(text[start:end])


    def extract_params(self, paramstring):
        def split(paramstring):
            for p in paramstring.split(';'):
                if p != '':
                    yield int(p)
        return tuple(split(paramstring))


    def call_win32(self, command, params):
        if command == 'm':
            for param in params:
                if param in win32_calls:
                    win32_calls[param]()





from contextlib import contextmanager
import sys
from unittest2 import TestCase, main

import colorama
from colorama import AnsiToWin32
from colorama.ansitowin32 import winterm

from mock import Mock, patch

@contextmanager
def platform(name):
    orig = sys.platform
    sys.platform = name
    yield
    sys.platform = orig


class AnsiToWin32Test(TestCase):

    def tearDown(self):
        winterm.reset_all()

    def testInit(self):
        mockStdout = object()
        auto = object()
        stream = AnsiToWin32(mockStdout, autoreset=auto)
        self.assertEquals(stream.wrapped, mockStdout)
        self.assertEquals(stream.autoreset, auto)

    def testEnabledOnWindows(self):
        with platform('windows'):
            stream = AnsiToWin32(None)
            self.assertTrue(stream.enabled)

    def testDisabledOffWindows(self):
        with platform('darwin'):
            stream = AnsiToWin32(None)
            self.assertFalse(stream.enabled)

    def testIsAProxy(self):
        mock = Mock()
        atw32 = AnsiToWin32( mock )
        self.assertTrue( atw32.random_attr is mock.random_attr )

    def testWriteConvertsIfEnabled(self):
        mockStdout = Mock()
        stream = AnsiToWin32(mockStdout)
        stream.wrapped = Mock()
        stream.write_and_convert = Mock()
        stream.enabled = True

        stream.write('abc')

        self.assertFalse(stream.wrapped.write.called)
        self.assertEquals(stream.write_and_convert.call_args, (('abc',), {}))

    def testWriteDoesNotConvertIfDisabled(self):
        mockStdout = Mock()
        stream = AnsiToWin32(mockStdout)
        stream.wrapped = Mock()
        stream.write_and_convert = Mock()
        stream.enabled = False

        stream.write('abc')
        
        self.assertFalse(stream.write_and_convert.called)
        self.assertEquals(stream.wrapped.write.call_args, (('abc',), {}))

    def testWriteAutoresetsIfOn(self):
        stream = AnsiToWin32(Mock())
        stream.enabled = True
        stream.write_and_convert = Mock()
        stream.autoreset = True
        stream.winterm = Mock()

        stream.write('abc')
        
        self.assertEqual(
            stream.winterm.method_calls[-1],
            ('reset_all', (), {}) )

    def testWriteDoesntAutoresetIfOff(self):
        stream = AnsiToWin32(Mock())
        stream.enabled = True
        stream.write_and_convert = Mock()
        stream.autoreset = False
        stream.winterm = Mock()

        stream.write('abc')
        
        self.assertEqual(stream.winterm.method_calls, [])

    def testWriteAndConvertWritesPlainText(self):
        stream = AnsiToWin32(Mock())
        stream.write_and_convert( 'abc' )
        self.assertEquals( stream.wrapped.write.call_args, (('abc',), {}) )

    def testWriteAndConvertStripsAllValidAnsi(self):
        stream = AnsiToWin32(Mock())
        data = [
            'abc\033[mdef',
            'abc\033[0mdef',
            'abc\033[2mdef',
            'abc\033[02mdef',
            'abc\033[002mdef',
            'abc\033[40mdef',
            'abc\033[040mdef',
            'abc\033[0;1mdef',
            'abc\033[40;50mdef',
            'abc\033[50;30;40mdef',
            'abc\033[Adef',
            'abc\033[0Gdef',
            'abc\033[1;20;128Hdef',
        ]
        for datum in data:
            stream.wrapped.write.reset_mock()
            stream.write_and_convert( datum )
            self.assertEquals(
               [args[0] for args in stream.wrapped.write.call_args_list],
               [ ('abc',), ('def',) ]
            )

    def testWriteAndConvertSkipsEmptySnippets(self):
        stream = AnsiToWin32(Mock())
        stream.write_and_convert( '\033[40m\033[41m' )
        self.assertFalse( stream.wrapped.write.called )

    def testWriteAndConvertCallsWin32WithParamsAndCommand(self):
        stream = AnsiToWin32(Mock())
        stream.call_win32 = Mock()
        stream.extract_params = Mock(return_value='params')
        data = {
            'abc\033[adef':         ('a', 'params'),
            'abc\033[;;bdef':       ('b', 'params'),
            'abc\033[0cdef':        ('c', 'params'),
            'abc\033[;;0;;Gdef':    ('G', 'params'),
            'abc\033[1;20;128Hdef': ('H', 'params'),
        }
        for datum, expected in data.iteritems():
            stream.call_win32.reset_mock()
            stream.write_and_convert( datum )
            self.assertEquals( stream.call_win32.call_args[0], expected )

    def testExtractParams(self):
        stream = AnsiToWin32(Mock())
        data = {
            '':               (),
            ';;':             (),
            '2':              (2,),
            ';;002;;':        (2,),
            '0;1':            (0, 1),
            ';;003;;456;;':   (3, 456),
            '11;22;33;44;55': (11, 22, 33, 44, 55),
        }
        for datum, expected in data.iteritems():
            self.assertEquals(stream.extract_params(datum), expected)

    @patch('colorama.ansitowin32.win32_calls', {})
    def testCallWin32UsesLookup(self):
        listener = Mock()
        colorama.ansitowin32.win32_calls.clear()
        colorama.ansitowin32.win32_calls.update( {
            1: lambda: listener(11),
            2: lambda: listener(22),
            3: lambda: listener(33),
        } )
        stream = AnsiToWin32(Mock())
        stream.call_win32('m', (3, 1, 99, 2))
        self.assertEquals(
            [a[0][0] for a in listener.call_args_list],
            [33, 11, 22] )


if __name__ == '__main__':
    main()




from os.path import dirname, join
from setuptools import setup, find_packages

name = 'colorama'
version = '0.1.5'

def get_long_description(filename):
    readme = join(dirname(__file__), filename)
    return open(readme).read()


setup(
    name=name,
    version=version,
    description="Cross-platform colored terminal text.",
    long_description=get_long_description('README.txt'),
    keywords='color colour terminal text ansi windows crossplatform xplatform',
    author='Jonathan Hartley',
    author_email='tartley@tartley.com',
    url='http://code.google.com/p/colorama/',
    license='BSD',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=True,
    install_requires=[
      # -*- Extra requirements: -*-
    ],
    entry_points="""
# -*- Entry points: -*-
    """,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.6',
        'Topic :: Terminals',
    ]
    # see classifiers http://pypi.python.org/pypi?%3Aaction=list_classifiers
)





from unittest2 import TestCase, main

from mock import patch, Mock

from ..winterm import WinColor, HANDLE, WinStyle, WinTerm

class WinTermTest(TestCase):

    def testInit(self):
        term = WinTerm()
        self.assertEquals(term._fore, WinColor.GREY)
        self.assertEquals(term._back, WinColor.BLACK) 
        self.assertEquals(term._style, WinStyle.NORMAL) 

    def testDefaults(self):
        self.fail('default fore and back should read from terminal current')

    def testCombinedAttrs(self):
        term = WinTerm()

        term._fore = 0
        term._back = 0
        term._style = 0
        self.assertEquals(term.combined_attrs, 0)

        term._fore = WinColor.YELLOW
        self.assertEquals(term.combined_attrs, WinColor.YELLOW)

        term._back = WinColor.MAGENTA
        self.assertEquals(
            term.combined_attrs,
            WinColor.YELLOW + WinColor.MAGENTA * 16)

        term._style = WinStyle.BRIGHT
        self.assertEquals(
            term.combined_attrs,
            WinColor.YELLOW + WinColor.MAGENTA * 16 + WinStyle.BRIGHT)

    def testResetAll(self):
        term = WinTerm()
        term.set_console = Mock()
        term._fore = -1
        term._back = -1
        term._style = -1

        term.reset_all()

        self.assertEquals(term._fore, WinColor.GREY)
        self.assertEquals(term._back, WinColor.BLACK)
        self.assertEquals(term._style, WinStyle.NORMAL)
        self.assertEquals(term.set_console.called, True)

    def testFore(self):
        term = WinTerm()
        term.set_console = Mock()
        term._fore = 0

        term.fore(5)

        self.assertEquals(term._fore, 5)
        self.assertEquals(term.set_console.called, True)
    
    def testBack(self):
        term = WinTerm()
        term.set_console = Mock()
        term._back = 0

        term.back(5)

        self.assertEquals(term._back, 5)
        self.assertEquals(term.set_console.called, True)
        
    def testStyle(self):
        term = WinTerm()
        term.set_console = Mock()
        term._style = 0

        term.style(22)

        self.assertEquals(term._style, 22)
        self.assertEquals(term.set_console.called, True)

    @patch('colorama.winterm.windll.kernel32')
    def test_set_console(self, kernel32):
        term = WinTerm()
        term.set_console()
        self.assertEquals(
            kernel32.SetConsoleTextAttribute.call_args,
            ((HANDLE, term.combined_attrs), {})
        )


if __name__ == '__main__':
    main()

